//*****************************************
// AT mega328P-PU(28pin 300mil SDIP) Fifteen IN-17 Clock Program
// CPU Clock:8MHz
//   iq[Yf[^@WȂBIV[^(8MHz)ɂj
//
// File Name:nixie.c
//
//  2017/09/13 New TAB4 Taishi
//  2017/12/13 Ver 2.00 Taishi
//  2018/10/25 Modify for Fifteen IN-17 Clock Taishi
//*****************************************

#include	<avr/pgmspace.h>
#include	<avr/io.h>

#include	"fifteen_in17_clock.h"
#include	"nixie.h"

// **********************************************************
// *********************** NIXE TUBE ************************
// **********************************************************
//

// **********************************************************
//@jLV[ǂ͂O`VAlIǂ͂WFR\
//@@jLV[ǑÍ@(WjubNƉʁiVjubNʂ
//@@obO`R̃R[hɂđI
//@@@R@Q@P@O
//@@@k@k@k@k@||@O@@̉
//@@@k@k@k@g@||@P@@̏㌅@@j
//@@@k@k@g@k@||@Q@@̉@@b̉
//@@@k@k@g@g@||@R@@̏㌅@@b̏㌅
//@@@k@g@k@k@||@S@@N̍ŉʁ@̉
//@@@k@g@k@g@||@T@@N̂RԖځ@̏㌅
//@@@k@g@g@k@||@U@@N̂QԖځ@̉
//@@@k@g@g@g@||@V@@N̍ŏʁ@̏㌅
//@@@g@k@k@k@||@W@@R
//@@@g@k@k@g@||@X@@IȂiA ݂̓Rj
//@@@g@k@g@k@||@PO@IȂiA ݂̓Rj
//@@@g@k@g@g@||@PP@IȂiA ݂̓Rj
//@@@g@g@k@k@||@PQ@IȂiA ݂̓Rj
//@@@g@g@k@g@||@PR@IȂiA ݂̓Rj
//@@@g@g@g@k@||@PS@IȂiA ݂̓Rj
//@@@g@g@g@g@||@PT@IȂiA ݂̓Rj
//
//@@@ʃubNiNAAj
//@@\locSCTCUCV̂Srbĝabcōs
//@@@V@U@T@S
//@@@k@k@k@k@||@O
//@@@k@k@k@g@||@P
//@@@k@k@g@k@||@Q
//@@@k@k@g@g@||@R
//@@@k@g@k@k@||@S
//@@@k@g@k@g@||@T
//@@@k@g@g@k@||@U
//@@@k@g@g@g@||@V
//@@@g@k@k@k@||@W
//@@@g@k@k@g@||@X
//@@@g@k@g@k@||@
//@@@g@k@g@g@||@
//@@@g@g@k@k@||@
//@@@g@g@k@g@||@
//@@@g@g@g@k@||@
//@@@g@g@g@g@||@
//
//@@@ʃubNiAAbAjj
//@@\loaOCocPCoaPCocR̂Srbĝabcōs
//@@@ocR@oaP@ocP@oaO
//@@@k@@@k@@@k@@@k@@||@O
//@@@k@@@k@@@k@@@g@@||@P
//@@@k@@@k@@@g@@@k@@||@Q
//@@@k@@@k@@@g@@@g@@||@R
//@@@k@@@g@@@k@@@k@@||@S
//@@@k@@@g@@@k@@@g@@||@T
//@@@k@@@g@@@g@@@k@@||@U
//@@@k@@@g@@@g@@@g@@||@V
//@@@g@@@k@@@k@@@k@@||@W
//@@@g@@@k@@@k@@@g@@||@X
//@@@g@@@k@@@g@@@k@@||@
//@@@g@@@k@@@g@@@g@@||@
//@@@g@@@g@@@k@@@k@@||@
//@@@g@@@g@@@k@@@g@@||@
//@@@g@@@g@@@g@@@k@@||@
//@@@g@@@g@@@g@@@g@@||@
//
//@@R\́@gF_AkF@
//@@@ocVF@R@NE̊
//@@@ocUF@R@E̊
//@@@ocTF@R@E̊
//@@@ocSF@R@j̉E
//@@@ocRF@R@E̊
//@@@oaPF@R@Eb̊
//
// **********************************************************

unsigned char	path_limit = 1;

static	unsigned char	nixie_hdata[KETA_SEL_MAX+1];
static	unsigned char	nixie_lpddata[KETA_SEL_MAX+1];
static	unsigned char	nixie_lpbdata[KETA_SEL_MAX+1];
static	unsigned char	nixie_select[KETA_SEL_MAX+1];
static	unsigned char	nixie_act_num = 0;
static	unsigned char	dynamic_nixie = 0;
static	unsigned char	nixie_dot_pd = 0;
static	unsigned char	nixie_dot_pb = 0;

#define		NIXE_HDATA_MASK		0b00001111	// PD 4--7 High Data Mask Port-D
#define		NIXE_LDATA_PDMASK	0b11110101	// PD 1,3 Low Data Mask Port-D
#define		NIXE_LDATA_PBMASK	0b11110011	// PB 0,1 Low Data Mask Port-B
#define		NIXE_SELECT_CLR		0b11110000	// PC0 -- 3 Clear
#define		NIXE_SELECT_NON		0b00001001	// PC0 -- 3 = 9
#define		NIXE_HNUMBER_OFF	0b11110000	// PD4--7:'H'
#define		NIXE_HNUMBER_MASK	0b00001111	// PD4--7:'L'ɂ鎞
#define		NIXE_LNUMBER_PDOFF	0b00001010	// PD1,3:'H'
#define		NIXE_LNUMBER_PDMASK	0b11110101	// PD1,3:'L'ɂ鎞
#define		NIXE_LNUMBER_PBOFF	0b00000011	// PB0,1:'H'
#define		NIXE_LNUMBER_PBMASK	0b11111100	// PB0,1:'L'ɂ鎞
#define		NIXE_YMCOLON_ON		0b10000000	// Colon ON NE̊
#define		NIXE_YMCOLON_OFF	0b01111111	// Colon OFF NE̊
#define		NIXE_MDCOLON_ON		0b01000000	// Colon ON E̊
#define		NIXE_MDCOLON_OFF	0b10111111	// Colon OFF E̊
#define		NIXE_DHCOLON_ON		0b00100000	// Colon ON E̊
#define		NIXE_DHCOLON_OFF	0b11011111	// Colon OFF E̊
#define		NIXE_HMCOLON_ON		0b00001000	// Colon ON E̊
#define		NIXE_HMCOLON_OFF	0b11110111	// Colon OFF E̊
#define		NIXE_WCOLON_ON		0b00010000	// Colon ON j̉E
#define		NIXE_WCOLON_OFF		0b11101111	// Colon OFF j̉E
#define		NIXE_MSCOLON_ON		0b00000010	// Colon ON E̊ Port-B
#define		NIXE_MSCOLON_OFF	0b11111101	// Colon OFF E̊ Port-B

//#define		NIXE_DATA_MASK		0x0d	// PD 1,4--7 Data Mask
//#define		NIXE_SELECT_CLR		0xe0	// PC0 -- 4 Clear
//#define		NIXE_NUMBER_OFF		0xf0	// PD4--7:'H'
//#define		NIXE_NUMBER_MASK	0x0f	// PD4--7:'L'ɂ鎞
//#define		NIXE_COLON_ON		0x02	// Colon ON
//#define		NIXE_COLON_OFF		0x00	// Colon OFF

//******************************
//  Nixe\@
// *****************************
void	init_nixe(void)
{
	unsigned char	uc;

	PORTC &= NIXE_SELECT_CLR;					// IO
	PORTC |= NIXE_SELECT_NON;					// IȂ

	PORTD &= NIXE_HDATA_MASK;					// ʐ}XN
	PORTD |= NIXE_HNUMBER_OFF;					// ʐȂ

	PORTD &= NIXE_LDATA_PDMASK;					// ʐ}XN Port-D
	PORTD |= NIXE_LNUMBER_PDOFF;				// ʐȂ Port-D
	PORTB &= NIXE_LDATA_PBMASK;					// ʐ}XN Port-B
	PORTB |= NIXE_LNUMBER_PBOFF;				// ʐȂ Port-B

	PORTD &= (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);		// ROFF Port-D
	PORTB &= (NIXE_MSCOLON_OFF);				// ROFF Port-B
	DDRD |= ((1 << DDD1) | (1 << DDD3) | (1 << DDD4) | (1 << DDD5) | (1 << DDD6) | (1 << DDD7));	// Port-D Bit1,34567 : Output
	DDRC |= ((1 << DDC0) | (1 << DDC1) | (1 << DDC2) | (1 << DDC3));	// Port-C Bit0123 : Output
	DDRB |= ((1 << DDB0) | (1 << DDB1));		// Port-B Bit01 : Output

// \AR f[^
	for(uc = 0;uc <= KETA_SEL_MAX; uc++){
		nixie_hdata[uc] = NIXE_HNUMBER_OFF;		// NA
		nixie_lpddata[uc] = NIXE_LNUMBER_PDOFF;		// NA
		nixie_lpbdata[uc] = NIXE_LNUMBER_PBOFF;		// NA
	}

	nixie_dot_pd = (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);			// RNA
	nixie_dot_pb = (NIXE_MSCOLON_OFF);			// RNA

	nixie_select[0] = 0b00000111;		// ŏʁ@N̍ŏʁ@̏㌅
	nixie_select[1] = 0b00000110;		// Qʁ@N̂QԖځ@̉
	nixie_select[2] = 0b00000101;		// Rʁ@N̂RԖځ@̏㌅
	nixie_select[3] = 0b00000100;		// Sʁ@N̍ŉʁ@̉
	nixie_select[4] = 0b00000011;		// Tʁ@̏㌅@@b̏㌅
	nixie_select[5] = 0b00000010;		// Uʁ@̉@@b̉
	nixie_select[6] = 0b00000001;		// Vʁ@̏㌅@@j
	nixie_select[7] = 0b00000000;		// ŉʁ@̉
	nixie_select[8] = 0b00001000;		// R


	nixie_act_num = 0;

	dynamic_nixie = 0;


}
//******************************
// jLV[Ǖ\
// sQ̊荞݂ŌĂ΂
//  d͖TO`Ȃ邪A邭Ȃ
//  for Fifteen IN-17 Clock
//******************************
void	proc_dynamic_nixie(void)
{
	static	unsigned char	path=0;
	unsigned char	uc;

	if(dynamic_nixie == 1){
		if(path == path_limit){

			uc = PORTC;										// o|b̒lǂ
			uc &= NIXE_SELECT_CLR;							// IO
			uc |= NIXE_SELECT_NON;							// IȂ
			PORTC = uc;										// o|bɒl
			PORTD |= NIXE_HNUMBER_OFF;						// ʐȂ
			PORTD |= NIXE_LNUMBER_PDOFF;					// ʐȂ Port-D
			PORTB |= NIXE_LNUMBER_PBOFF;					// ʐȂ Port-B
			PORTD &= (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);		// ROFF Port-D
			PORTB &= (NIXE_MSCOLON_OFF);																				// ROFF Port-B
			if(nixie_act_num <= (KETA_SEL_MAX - 1)){		// ijLV[ǁj
				PORTD &= NIXE_HNUMBER_MASK;					// ʐ}XN
				PORTD &= NIXE_LNUMBER_PDMASK;				// ʐ}XN Port-D
				PORTB &= NIXE_LNUMBER_PBMASK;				// ʐ}XN Port-B
				PORTD |= nixie_hdata[nixie_act_num];		// ʐ
				PORTD |= nixie_lpddata[nixie_act_num];		// ʐiocj
				PORTB |= nixie_lpbdata[nixie_act_num];		// ʐioaj
				uc    &= NIXE_SELECT_CLR;					// IO
				uc    |= nixie_select[nixie_act_num];		// I
				PORTC = uc;									// o|bɒl
			}else if(nixie_act_num == KETA_SEL_MAX){		// RilIǁj
				PORTD |= nixie_dot_pd;						// ocR
				PORTB |= nixie_dot_pb;						// oaR
				uc    &= NIXE_SELECT_CLR;					// IO
				uc    |= nixie_select[nixie_act_num];		// I
				PORTC = uc;									// o|bɒl
			}

			if(KETA_SEL_MAX <= nixie_act_num){
				nixie_act_num = 0;
			}else{
				nixie_act_num++;
			}
		}else if(path == 0){
			uc = PORTC;										// o|b̒lǂ
			uc &= NIXE_SELECT_CLR;							// IO
			uc |= NIXE_SELECT_NON;							// IȂ
			PORTC = uc;										// o|bɒl
			PORTD |= NIXE_HNUMBER_OFF;						// ʐȂ
			PORTD |= NIXE_LNUMBER_PDOFF;					// ʐȂ Port-D
			PORTB |= NIXE_LNUMBER_PBOFF;					// ʐȂ Port-B
			PORTD &= (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);		// ROFF Port-D
			PORTB &= (NIXE_MSCOLON_OFF);																				// ROFF Port-B
		}

		path++;
		if(PATH_MAX < path){
			path = 0;
		}

	}
}
#if	0
//******************************
// jLV[Ǖ\
// sQ̊荞݂ŌĂ΂
//  d͖TO`Ȃ邪A邭Ȃ
//******************************
void	old_proc_dynamic_nixie(void)
{
	static	unsigned char	path=0;
	unsigned char	dd;

	if(dynamic_nixie == 1){
		if(path == path_limit){
			PORTC &= NIXE_SELECT_CLR;						// [0xe0]IȂ
			PORTD |= NIXE_NUMBER_OFF;						// 
			if(nixie_act_num <= (g_keta - 1)){
				PORTD &= ~(NIXE_COLON_ON);						// Rnee
				PORTD &= NIXE_NUMBER_MASK;						// 
				PORTD |= nixie_data[nixie_act_num];				// 
				PORTC |= nixie_select[nixie_act_num];			// I
			}else if(nixie_act_num == g_keta){
				dd = nixie_dot[nixie_act_num];
				if((dd & NIXE_COLON_ON) != 0){					// Rnm̎
					PORTD |= NIXE_COLON_ON;						// Rnm
				}else{
					PORTD &= ~NIXE_COLON_ON;					// Rnee
				}
				PORTC |= nixie_select[nixie_act_num];			// I
			}
			if(g_keta < nixie_act_num){
				nixie_act_num = 0;
			}else{
				nixie_act_num++;
			}
		}else if(path == 0){
			PORTC &= NIXE_SELECT_CLR;						// [0xe0]IȂ
			PORTD |= NIXE_NUMBER_OFF;						// 
			PORTD &= ~(NIXE_COLON_ON);						// Rnee
		}

		path++;
		if(PATH_MAX < path){
			path = 0;
		}

	}
}
//******************************
// jLV[Ǖ\
// sQ̊荞݂ŌĂ΂
//  d͖TO`Ȃ邪A邭Ȃ
//  ̂O`R͐ SڂRɂ
//******************************
void	old_old_proc_dynamic_nixie(void)
{
	static	unsigned char	path=0;
	unsigned char	dd;

	if(dynamic_nixie == 1){
		PORTC &= NIXE_SELECT_CLR;						// [0xe0]IȂ
		PORTD |= NIXE_NUMBER_OFF;						// 
		if(path == 0){
			if(nixie_act_num <= (g_keta - 1)){
				PORTD &= ~(NIXE_COLON_ON);						// Rnee
				PORTD &= NIXE_NUMBER_MASK;						// 
				PORTD |= nixie_data[nixie_act_num];				// 
				PORTC |= nixie_select[nixie_act_num];			// I
			}else if(nixie_act_num == g_keta){
				dd = nixie_dot[nixie_act_num];
				if((dd & NIXE_COLON_ON) != 0){					// Rnm̎
					PORTD |= NIXE_COLON_ON;						// Rnm
				}else{
					PORTD &= ~NIXE_COLON_ON;					// Rnee
				}
				PORTC |= nixie_select[nixie_act_num];			// I
			}
			if(g_keta < nixie_act_num){
				nixie_act_num = 0;
			}else{
				nixie_act_num++;
			}
		}else{
			PORTD |= NIXE_NUMBER_OFF;						// 
			PORTD &= ~(NIXE_COLON_ON);						// Rnee
		}

		path++;
		if(path_limit <= path){
			path = 0;
		}

	}
}
#endif

//******************************
// Dynamic Nixie display Active/Non active
//  on : 1= Active, other=Non Active
// *****************************
void	dynamic_nixie_active(unsigned char on)
{
	dynamic_nixie = on;
}
//******************************
// Nixie \i_Ci~bN_j
//  k : ʒuiO`PSAOFŏʁEEEPSFŉʁj
//  n : O`XAPTiPT͋󔒁j
//@@@ocR@oaP@ocP@oaO
//@@@k@@@k@@@k@@@k@@||@O
//@@@k@@@k@@@k@@@g@@||@P
// *****************************
void	disp_dynamic_nixie_number(unsigned char k, unsigned char n)
{
	if(KETA_SEL_MAX <= k/2){					// IlُȎ
		k = 0;									// Iɍŏʂɂ
	}
	if(k < (KETA_MAX/2)){
		nixie_hdata[k] = ((n << 4) & 0xf0);
	}else{
		dynamic_nixie_active(0);				// _Ci~bN\~
		nixie_lpbdata[k-(KETA_MAX/2)] = 0;
		nixie_lpddata[k-(KETA_MAX/2)] = 0;
		nixie_lpbdata[k-(KETA_MAX/2)] |= (n & 0b00000001);
		nixie_lpddata[k-(KETA_MAX/2)] |= (n & 0b00001010);
		if((n & 0b00000100) !=0 ){
			nixie_lpbdata[k-(KETA_MAX/2)] |= 0b00000010;
		}
		dynamic_nixie_active(1);				// _Ci~bN\ĊJ
	}
}
//******************************
// Nixie \SARi_Ci~bN_j
// *****************************
void	disp_dynamic_nixie_clear(void)
{
	unsigned char uc;

	for(uc=0;uc < (KETA_MAX-1); uc++){
		disp_dynamic_nixie_number(uc, 15);				//   
	}
	disp_dynamic_colon(0);								// R
}
//******************************
// S̃R\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd = (NIXE_YMCOLON_ON | NIXE_MDCOLON_ON | NIXE_DHCOLON_ON | NIXE_HMCOLON_ON | NIXE_WCOLON_ON);		// RON Port-D
		nixie_dot_pb = (NIXE_MSCOLON_ON);																				// RON Port-B
	}else{
		nixie_dot_pd = (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);	// ROFF Port-D
		nixie_dot_pb = (NIXE_MSCOLON_OFF);																				// ROFF Port-B
	}
}

//******************************
// NER\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_ym_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd |= NIXE_YMCOLON_ON;	// RON Port-D
	}else{
		nixie_dot_pd &= NIXE_YMCOLON_OFF;	// ROFF Port-D
	}
}

//******************************
// ER\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_md_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd |= NIXE_MDCOLON_ON;	// RON Port-D
	}else{
		nixie_dot_pd &= NIXE_MDCOLON_OFF;	// ROFF Port-D
	}
}

//******************************
// ER\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_dh_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd |= NIXE_DHCOLON_ON;	// RON Port-D
	}else{
		nixie_dot_pd &= NIXE_DHCOLON_OFF;	// ROFF Port-D
	}
}

//******************************
// ER\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_hm_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd |= NIXE_HMCOLON_ON;	// RON Port-D
	}else{
		nixie_dot_pd &= NIXE_HMCOLON_OFF;	// ROFF Port-D
	}
}

//******************************
// jR\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_w_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pd |= NIXE_WCOLON_ON;		// RON Port-D
	}else{
		nixie_dot_pd &= NIXE_WCOLON_OFF;	// ROFF Port-D
	}
}

//******************************
// EbR\i_Ci~bN_j
//       d : \iO`PAOF\ȂAPF\j
// *****************************
void	disp_dynamic_ms_colon(unsigned char d)
{
	if(d == 1){
		nixie_dot_pb |= NIXE_MSCOLON_ON;	// RON Port-B
	}else{
		nixie_dot_pb &= NIXE_MSCOLON_OFF;	// ROFF Port-B
	}
}

//******************************
// Nixie \iX^eBbNN_j
//  k : ʒuiO`PTAOFŏʁEEEPTFŉʁj
//  n : O`XAPTiPT͋󔒁j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_nixie_number(unsigned char k, unsigned char n)
{
	unsigned char	uc;

	uc = PORTC;									// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;						// IO
	uc |= NIXE_SELECT_NON;						// IȂ
	PORTC = uc;									// o|bɒl
	PORTD |= NIXE_HNUMBER_OFF;					// ʐȂ
	PORTD |= NIXE_LNUMBER_PDOFF;				// ʐȂ Port-D
	PORTB |= NIXE_LNUMBER_PBOFF;				// ʐȂ Port-B

	if(KETA_MAX <= k){							// IlُȎ
		k = 0;									// Iɍŏʂɂ
	}

	if(k < KETA_MAX/2){							// W̎
		PORTD &= NIXE_HNUMBER_MASK;				// }XN
		PORTD |= ((n << 4) & 0xf0);				// 
//		PORTC |= nixie_select[k];				// I
	}else{
		k -= KETA_MAX/2;
		PORTD &= NIXE_LNUMBER_PDMASK;			// ʐ}XN Port-D
		PORTB &= NIXE_LNUMBER_PBMASK;			// ʐ}XN Port-B
		PORTB |= (n & 0b00000001);
		PORTD |= (n & 0b00001010);
		if((n & 0b00000100) !=0 ){
			PORTB |= 0b00000010;
		}
	}

	uc &= NIXE_SELECT_CLR;						// IO
	uc |= nixie_select[k];						// I
	PORTC = uc;									// o|bɒl

}
//******************************
// SR\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= (NIXE_YMCOLON_ON | NIXE_MDCOLON_ON | NIXE_DHCOLON_ON | NIXE_HMCOLON_ON | NIXE_WCOLON_ON);		// RON Port-D
		PORTB |= (NIXE_MSCOLON_ON);																				// RON Port-B
	}else{
		PORTD &= (NIXE_YMCOLON_OFF & NIXE_MDCOLON_OFF & NIXE_DHCOLON_OFF & NIXE_HMCOLON_OFF & NIXE_WCOLON_OFF);	// ROFF Port-D
		PORTB &= (NIXE_MSCOLON_OFF);																			// ROFF Port-B
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

//******************************
// NER\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_ym_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= NIXE_YMCOLON_ON;	// RON Port-D
	}else{
		PORTD &= NIXE_YMCOLON_OFF;	// ROFF Port-D
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl

}

//******************************
// ER\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_md_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= NIXE_MDCOLON_ON;	// RON Port-D
	}else{
		PORTD &= NIXE_MDCOLON_OFF;	// ROFF Port-D
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

//******************************
// ER\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_dh_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= NIXE_DHCOLON_ON;	// RON Port-D
	}else{
		PORTD &= NIXE_DHCOLON_OFF;	// ROFF Port-D
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

//******************************
// ER\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_hm_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= NIXE_HMCOLON_ON;	// RON Port-D
	}else{
		PORTD &= NIXE_HMCOLON_OFF;	// ROFF Port-D
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

//******************************
// jR\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_w_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTD |= NIXE_WCOLON_ON;	// RON Port-D
	}else{
		PORTD &= NIXE_WCOLON_OFF;	// ROFF Port-D
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

//******************************
// EbR\iX^eBbN_j
//       d : \iO`PAOF\ȂAPF\j
//   _Ci~bN\͍sĂȂԂɌ
// *****************************
void	disp_static_ms_colon(unsigned char d)
{
	unsigned char	uc;

	uc = PORTC;						// o|b̒lǂ
	uc &= NIXE_SELECT_CLR;			// IO
	uc |= NIXE_SELECT_NON;			// IȂ
	PORTC = uc;						// o|bɒl

	if(d == 1){
		PORTB |= NIXE_MSCOLON_ON;	// RON Port-B
	}else{
		PORTB &= NIXE_MSCOLON_OFF;	// ROFF Port-B
	}

	uc &= NIXE_SELECT_CLR;			// IO
	uc |= nixie_select[8];			// I
	PORTC = uc;						// o|bɒl
}

